<?php

//
// Logging. Must be initialized first, i.e. before any object construction.
//
/*require_once '../lib/aviberry/logger.class.php';
$logger = Members_Logger::getLog(
	'api_index',
	Members_Log::DEBUG,
	false,
	dirname(__FILE__) . '/../debug/'
);
set_error_handler(array($logger, 'handleError'));
set_exception_handler(array($logger, 'handleException'));*/

// Wordpress functionality.
require_once '../../../../wp-load.php';
// Plugin functionality.
require_once '../lib/aviberry/aviberryPlugin.class.php';
// RPC Server functionality.
if (!class_exists('DateTime'))
	require_once '../lib/json-rpc/DateTime.class.php';

require_once '../lib/json-rpc/ApiException.class.php';
require_once '../lib/json-rpc/ApiServer.class.php';
require_once '../lib/json-rpc/ApiClient.class.php'; //json



$rpcServer = ApiServer::getInstance(ApiServer::JSON, ApiServer::PUBLIC_VISIBILITY, false);
//$rpcServer = RPCServer::getInstance();

$rpcClient = new ApiClient(str_replace(
	array(
		'{$api_key}',
		'{$api_pass}',
		'{$api_host}'
	),
	array(
		aviberryPlugin::getOption('aviberry_api_key'),
		aviberryPlugin::getOption('aviberry_api_pass'),
		aviberryPlugin::getOption('aviberry_api_host')
	),
	AVIBERRY_API_URL_AUTHORIZED
));



/**
* 
*/
function startConversion(
	$source_url, 
	$target_url, 
	$preset,
	$title
) {
	global $rpcClient;
	
	// Callback
	$callback = array(
		'url' => AVIBERRY_PLUGIN_API_URL,
		'method' => 'register_files',
		'protocol' => 'json'
	);
	
	$method_params = array(
		'source_url' => $source_url,
		'target_url' => $target_url,
		'preset' => $preset,		
		'callback' => $callback,
		'params' => array(
			'target_filename_policy' => 'OVERWRITE_EXTENSION'
		),
		'data' => array(
			'title' => $title
		)
	);

	//Call aviberry API
	return $rpcClient->startConversion($method_params);
}


/**
* 
*/
function cancelConversion($conversion_id) {
	global $rpcClient;
	
	return $rpcClient->cancelConversion(
		array(
			'conversion_id' => $conversion_id
		)
	);
}


/**
* 
*/
function getProgress($conversion_id) {
	global $rpcClient;
	
	return $rpcClient->getProgress(
		array(
			'conversion_id' => $conversion_id
		)
	);
}


/**
* Convertion end callback 
*
* @param array( ... ) $conversion
*
* @return boolean success
* 
*/
function register_files($conversion) {
	/*global $logger;

	$args = func_get_args();
	$logger->logDebug(__METHOD__ . ': Step Into: %s', var_export($args, true));*/

	//if error code was set then exit
	if($conversion['error_code'])
		return true;

	$aviberry_storage_type = aviberryPlugin::getOption('aviberry_storage_type');

	switch ($aviberry_storage_type) {
		
		//media library
		case 'wp_media_lib_ftp':
		case 'wp_media_lib_ftps':
			// you must first include the image.php file
			// for the function wp_generate_attachment_metadata() to work
			require_once(ABSPATH . "wp-admin" . '/includes/image.php');

			//get upload path to media library
			$path   = aviberryPlugin::getOption('aviberry_storage_path'); // www/wordpress.xxx/wp-content/uploads/
			// Normalize path.
			$path = array_diff(explode('/', $path), array('')); // www/wordpress.xxx/wp-content/uploads
			$path = implode('/', $path); // www/wordpress.xxx/wp-content/uploads

			if(empty($path))
				return false;

			$target_url = $conversion['target_url'][0][0]; //ftp://user:password@host/www/wordpress.xxx/wp-content/uploads/2011/10/2_1317794798.flv

			//get the upload subdir was
			$subdir = explode($path, $target_url); // ftp://user:password@host/   /2011/10/2_1317794798.flv
			if(count($subdir) < 2)
				return false;
			$subdir = $subdir[count($subdir) - 1]; // /2011/10/2_1317794798.flv
			$filename = basename(rawurldecode($subdir)); // 2_1317794798.flv

			$wp_filetype = wp_check_filetype($filename, null);
			$attachment = array(
			   'post_mime_type' => $wp_filetype['type'],
			   'post_title' => $conversion['data']['title'],
			   'post_content' => '',
			   'post_status' => 'inherit'
			);

			/**
			 * $attachment
			 * $filename - (string) (optional) Location of the file on the server.
			 * 		Use absolute path and not the URI of the file.
			 * 		The file MUST be on the uploads directory
			 * 	WORDPRESS_DIR + $subdir
			 */
			$attach_id = wp_insert_attachment($attachment, $subdir); // /2011/10/2_1317794798.flv
			$attach_data = wp_generate_attachment_metadata($attach_id, $filename);
			wp_update_attachment_metadata($attach_id,  $attach_data);
			
			break;
	}

	return true;
}




/**
* 
*/
function startPostConversion($post_id, $conversion_id) {
	aviberryPlugin::startPostConversion($post_id, $conversion_id);
}

/**
* 
*/
function finishPostConversion($post_id) {
	aviberryPlugin::finishPostConversion($post_id);
}

// Proxy functions.
$rpcServer->addMethod("startConversion");
$rpcServer->addMethod("cancelConversion");
$rpcServer->addMethod("getProgress");
$rpcServer->addMethod("register_files");

// Plugin functions.
$rpcServer->addMethod("startPostConversion");
$rpcServer->addMethod("finishPostConversion");

$rpcServer->processRequest();
?>
