<?php
/**
 * @package aviberryPlugin
 * @author Aviberry
 * @link http://www.aviberry.com
 * @version 1.0.6
 */

/*
Plugin Name: Aviberry Plug-In
Plugin URI: http://www.aviberry.com
Description: Intergation of Aviberry Converter with Wordpress Media
Author: Aviberry
Version: 1.0.6
Author URI: http://www.aviberry.com
*/

/*
 * Definitions 
 */

// Pre-2.6 compatibility
defined('WP_CONTENT_URL')
	|| define('WP_CONTENT_URL', get_option('siteurl') . '/wp-content');
defined('WP_CONTENT_DIR')
	|| define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
defined('WP_PLUGIN_URL')
	|| define('WP_PLUGIN_URL', WP_CONTENT_URL. '/plugins');
defined('WP_PLUGIN_DIR')
	|| define('WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins');

/*
 * Requirements
 */

require_once 'lib/aviberry/aviberryPlugin.class.php';

/*
 * Actions
 */

// Admin
add_action('admin_init',         'aviberry_admin_init');
add_action('admin_menu',         'aviberry_admin_menu');
add_action('admin_print_styles', 'aviberry_admin_print_styles');
// WP
add_action('init',               'aviberry_init');
add_action('wp_enqueue_scripts', 'aviberry_enqueue_scripts');
add_action('wp_head',            'aviberry_head');

/*
 * Shortcodes
 */

if (aviberryPlugin::getOption('aviberry_use_player') && aviberryPlugin::getOption('aviberry_player_embedding_type') == 'shortcode')
	add_shortcode('aviberry-player', 'aviberry_player_shortcode_handler');

/*
 * Filters
 */

// Admin
add_filter('media_row_actions',                'aviberry_media_row_actions', 10, 2);
add_filter('pre_option_aviberry_storage_host', 'pre_option_aviberry_storage_host');
add_filter('media_send_to_editor',             'aviberry_media_send_to_editor', 10, 3);

/*
 * I18n
 */

load_plugin_textdomain('aviberry', 'wp-content/plugins/' . AVIBERRY_PLUGIN_DIR, AVIBERRY_PLUGIN_DIR);

/*
 * Hooks
 */

function aviberry_admin_init() {
	// Register our styles.
	wp_register_style('aviberry-admin',   AVIBERRY_PLUGIN_URL . 'css/aviberry/aviberry.css');
	wp_register_style('aviberry-tooltip', AVIBERRY_PLUGIN_URL . 'css/jquery/smoothness/jquery.tooltip.css');
	wp_register_style('aviberry-jquery',  AVIBERRY_PLUGIN_URL . 'css/jquery/smoothness/jquery-ui-1.7.2.custom.css');
	
	// Register our script with dependencies.
	
	// In hope that any other software use 'json-rpc' as identifier for 'rpc.js'.  
	wp_register_script('json-rpc',              AVIBERRY_PLUGIN_URL . 'js/json-rpc/rpc.js',               array());
	// In hope that any other software use 'jquery-ui-progressbar' as identifier for 'ui.progressbar.js'.
	wp_register_script('jquery-ui-progressbar', AVIBERRY_PLUGIN_URL . 'js/jquery/ui.progressbar.js',      array('jquery-ui-core'));
	// In hope that any other software use 'jquery-ui-dimensions' as identifier for 'jquery.dimensions.js'.
	wp_register_script('jquery-ui-dimensions',  AVIBERRY_PLUGIN_URL . 'js/jquery/jquery.dimensions.js',   array('jquery-ui-core'));
	// In hope that any other software use 'jquery-ui-tooltip' as identifier for 'jquery.tooltip.js'.
	wp_register_script('jquery-ui-tooltip',     AVIBERRY_PLUGIN_URL . 'js/jquery/jquery.tooltip.js',      array('jquery-ui-dimensions'));
	wp_register_script('aviberry-media',        AVIBERRY_PLUGIN_URL . 'js/aviberry/aviberry-media.js',    array('json-rpc', 'jquery-ui-dialog', 'jquery-ui-progressbar', 'jquery-ui-tooltip'));
	wp_register_script('aviberry-settings',     AVIBERRY_PLUGIN_URL . 'js/aviberry/aviberry-settings.js', array('jquery-ui-tooltip', 'jquery-ui-dialog'));
	
	// Register our options.
	aviberry_register_options();
}

function aviberry_init() {
	if (aviberryPlugin::getOption('aviberry_use_player') && aviberryPlugin::getOption('aviberry_player_embedding_type') == 'javascript')
		wp_register_script('aviberry-player', AVIBERRY_PLUGIN_URL . 'js/aviberry/aviberry-player.js', array('swfobject', 'jquery-ui-core'));
}	

function aviberry_admin_menu() {
	// Register our options page.
	$page = add_options_page(__('Aviberry Plug-In'), __('Aviberry Plug-In'), 'manage_options', 'aviberry_options', 'aviberry_add_options_page');
	
	// Hook admin scripts loading only for required pages.
	
	// "Media" page.
	add_action('admin_print_scripts-upload.php', 'aviberry_admin_print_scripts_media');
	add_action('admin_head-upload.php',          'aviberry_admin_head');
	
	// "Settings" page.
	add_action('admin_print_scripts-' . $page, 'aviberry_admin_print_scripts_settings');
	add_action('admin_head-'          . $page, 'aviberry_admin_head');
}

function aviberry_admin_head() {
	// Pass data to JS.
?>
<script type="text/javascript">
//<!--
var aviberryPlugin = {
	// Definitions
	AVIBERRY_S3_HOST:         "<?php echo AVIBERRY_S3_HOST;         ?>",
	AVIBERRY_WATCH_TIMEOUT:   <?php  echo AVIBERRY_WATCH_TIMEOUT;   ?>,
	AVIBERRY_PLUGIN_API_URL:  "<?php echo AVIBERRY_PLUGIN_API_URL;  ?>",
	
	// Options
	apiKey:              "<?php echo aviberryPlugin::getOption('aviberry_api_key');?>",
	apiPass:             "<?php echo aviberryPlugin::getOption('aviberry_api_pass');?>",
	storageType:         "<?php echo aviberryPlugin::getOption('aviberry_storage_type');?>",
	storageUser:         "<?php echo aviberryPlugin::getOption('aviberry_storage_user');?>",
	storagePass:         "<?php echo aviberryPlugin::getOption('aviberry_storage_pass');?>",
	storageHost:         "<?php echo aviberryPlugin::getOption('aviberry_storage_host');?>",
	storagePort:         "<?php echo aviberryPlugin::getOption('aviberry_storage_port');?>",
	storagePath:         "<?php echo aviberryPlugin::getOption('aviberry_storage_path');?>",
	storageUrl:          "<?php echo aviberryPlugin::getStorageUrl();?>",
	displayTooltips:     "<?php echo aviberryPlugin::getOption('aviberry_display_tooltips');?>",
	usePlayer:           "<?php echo aviberryPlugin::getOption('aviberry_use_player');?>",
	playerEmbeddingType: "<?php echo aviberryPlugin::getOption('aviberry_player_embedding_type');?>",
	playerWidth:         "<?php echo aviberryPlugin::getOption('aviberry_player_width');?>",
	playerHeight:        "<?php echo aviberryPlugin::getOption('aviberry_player_height');?>",
	
	// Strings
	i18n: {
		
		<?php
			aviberryPlugin::init();
			$i = 0;
			foreach(aviberryPlugin::$_i18n as $key => $value){
				if($i > 0) echo ",\n";
				echo $key . ": \"$value\"";
				$i++;
			}
		?>
	}
};
//-->
</script>
<div id="dlg_start_post_conversion" style="display: none;">
    <div class="message"></div>
    <div>
	    <select id="aviberry_preset_id" name="preset" class="icon-menu biginput">
			<optgroup label="AVI video, Xvid (.avi)" format_id="16500">
				<option value="442" id="presets_first_item" style="padding-left: 20px;">AVI - Audio-Video Interleaved</option>
			</optgroup>
			<optgroup label="MPEG-4 video (.mp4)" format_id="16505">

				<option value="446"  style="padding-left: 20px;">MPEG4 Video</option>
				<option value="2336" style="padding-left: 20px;">MPEG4 Video (High Quality)</option>
				<option value="896"  style="padding-left: 20px;">HD MPEG4 720p</option>
				<option value="2734" style="padding-left: 20px;">HD MPEG4 720p (High Quality)</option>
				<option value="899"  style="padding-left: 20px;">HD MPEG4 1080p</option>
				<option value="3148" style="padding-left: 20px;">HD MPEG4 1080p (High Quality)</option>

				<option value="901"  style="padding-left: 20px;">HD H.264 720p</option>
				<option value="3150" style="padding-left: 20px;">HD H.264 720p (High Quality)</option>
				<option value="903"  style="padding-left: 20px;">HD H.264 1080p</option>
				<option value="2736" style="padding-left: 20px;">HD H.264 1080p (High Quality)</option>
				<option value="920"  style="padding-left: 20px;">iPod (320x240)</option>
				<option value="2739" style="padding-left: 20px;">iPod (320x240) (High Quality)</option>

				<option value="921"  style="padding-left: 20px;">iPod 5G (640x480)</option>
				<option value="2740" style="padding-left: 20px;">iPod 5G (640x480) (High Quality)</option>
				<option value="924"  style="padding-left: 20px;">iPhone (480x320)</option>
				<option value="2744" style="padding-left: 20px;">iPhone (480x320) (High Quality)</option>
				<option value="934"  style="padding-left: 20px;">Video for PSP</option>
				<option value="2746" style="padding-left: 20px;">Video for PSP (High Quality)</option>
			</optgroup>

			<optgroup label="MPEG-2 video (.mpeg)" format_id="16501">
				<option value="8"   style="padding-left: 20px;">DVD PAL Compatible</option>
				<option value="7"   style="padding-left: 20px;">DVD NTSC Compatible</option>
				<option value="891" style="padding-left: 20px;">MPEG Best Quality</option>
				<option value="3"   style="padding-left: 20px;">VCD NTSC Compatible</option>
				<option value="4"   style="padding-left: 20px;">VCD PAL Compatible</option>

				<option value="5"   style="padding-left: 20px;">SVCD NTSC Compatible</option>
				<option value="6"   style="padding-left: 20px;">SVCD PAL Compatible</option>
			</optgroup>
			<optgroup label="WMV (.wmv)" format_id="16503">
				<option value="1493" style="padding-left: 20px;">WMV Video</option>
				<option value="13"   style="padding-left: 20px;">WMV 9 for VHS quality video</option>
				<option value="14"   style="padding-left: 20px;">WMV 9 for DVD quality video (1 mbps)</option>

				<option value="15"   style="padding-left: 20px;">WMV 9 for DVD quality video (2 mbps)</option>
				<option value="468"  style="padding-left: 20px;">WMV HD Video (720p, 4:3)</option>
				<option value="469"  style="padding-left: 20px;">WMV HD Video (1080p, 4:3)</option>
				<option value="467"  style="padding-left: 20px;">WMV HD Video (720p, 16:9)</option>
				<option value="470"  style="padding-left: 20px;">WMV HD Video (1080p, 16:9)</option>
				<option value="2334" style="padding-left: 20px;">Video for PowerPoint</option>

			</optgroup>
			<optgroup label="Best for video podcast, MPEG-4 video (.mov)" format_id="16508">
				<option value="892" style="padding-left: 20px;">QuickTime Video</option>
			</optgroup>
			<optgroup label="3GPP for cellphone (.3gp)" format_id="16506">
				<option value="894" style="padding-left: 20px;">Mobile Phone 3GP Video (352x288)</option>
			</optgroup>
			<optgroup label="3GPP2 for cellphone (.3gp2)" format_id="16507">
				<option value="895" style="padding-left: 20px;">Mobile Phone 3GP2 Video (352x288)</option>
			</optgroup>
			<optgroup label="Flash video (.flv)" format_id="16509">
				<option value="533" style="padding-left: 20px;">Optimal Quality (320x240)</option>
				<option value="542" style="padding-left: 20px;">Normal Quality (384x288)</option>
				<option value="543" style="padding-left: 20px;">Best Quality (480x360)</option>
				<option value="948" style="padding-left: 20px;">H.264 Flash Video</option>

				<option value="949" style="padding-left: 20px;">H.263 Flash Video</option>
			</optgroup>
			<optgroup label="WebM (.webm)" format_id="16520">
				<option value="2335" style="padding-left: 20px;">WebM</option>
			</optgroup>
			<optgroup label="MP3 audio (.mp3)" format_id="16511">
				<option value="120" style="padding-left: 20px;">MP3 High Quality</option>
			</optgroup>
		</select>
    </div>
</div>
<?php
}

function aviberry_admin_print_styles() {
	wp_enqueue_style('aviberry-admin');
	wp_enqueue_style('aviberry-tooltip');
	wp_enqueue_style('aviberry-jquery');
}

function aviberry_admin_print_scripts_media() {
	wp_enqueue_script('aviberry-media');
}

function aviberry_admin_print_scripts_settings() {
	wp_enqueue_script('aviberry-settings');
}

function aviberry_enqueue_scripts() {
	wp_enqueue_script('aviberry-player');
}

function aviberry_head() {
	// Pass data to JS.
?>
<script type="text/javascript">
//<!--
var aviberryPlugin = {
	// Definitions
	AVIBERRY_PLUGIN_URL: "<?php echo AVIBERRY_PLUGIN_URL; ?>",
	// Options
	playerWidth:  "<?php echo aviberryPlugin::getOption('aviberry_player_width');  ?>",
	playerHeight: "<?php echo aviberryPlugin::getOption('aviberry_player_height'); ?>"
};
//-->
</script>
<?php
}

function aviberry_player_shortcode_handler($atts, $content = null) {
	extract(shortcode_atts(
		array(
			'title'  => '',
			'href'   => '',
			'width'  => aviberryPlugin::getOption('aviberry_player_width'),
			'height' => aviberryPlugin::getOption('aviberry_player_height'),
			'id'     => ''
		),
      	$atts
	));
	
	$player = AVIBERRY_PLUGIN_URL . 'player.swf';
	$title  = esc_html($title);
	$href   = esc_attr($href);
	$width  = esc_attr($width);
	$height = esc_attr($height);
	$id     = esc_attr($id);
	
	return "
		<object classid=\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\" width=\"$width\" height=\"$height\" id=\"player-media-$id\" name=\"player-media-$id\" title=\"$title\">
			<param name=\"movie\" value=\"$player\"/>
			<param name=\"allowfullscreen\" value=\"true\"/>
			<param name=\"allowscriptaccess\" value=\"always\"/>
			<param name=\"flashvars\" value=\"file=$href\"/>
			<embed
				id=\"player-media-$id\"
				name=\"player-media-$id\"
				src=\"$player\"
				width=\"$width\"
				height=\"$height\"
				allowscriptaccess=\"always\"
				allowfullscreen=\"true\"
				flashvars=\"file=$href\"
			/>
		</object>
	";
}

function aviberry_media_send_to_editor($html, $send_id, $attachment) {
	if (aviberryPlugin::getOption('aviberry_use_player')) {
		$embedding_type = aviberryPlugin::getOption('aviberry_player_embedding_type');
		switch ($embedding_type) {
			case 'shortcode':
				$title  = $attachment['post_title'];
				$href   = $attachment['url'];
				$width  = aviberryPlugin::getOption('aviberry_player_width');
				$height = aviberryPlugin::getOption('aviberry_player_height');
				$html   = "[aviberry-player title=\"$title\" href=\"$href\" wdth=\"$width\" hight=\"$height\" id=\"$send_id\"/]";
				
				break;
				
			default: // By default as 'javascript'
				$title = esc_html($attachment['post_title']); 
				$href  = esc_attr($attachment['url']);
				$html  = "<a class=\"aviberry-player\" id=\"media-$send_id\" href=\"$href\">$title</a>";
				
				break;
		}
	}
	
	return $html;
}

/**
 * For storage type "s3" host always the same. 
 * 
 * @param string $value
 * @return string
 */
function pre_option_aviberry_storage_host($value) {
	if (aviberryPlugin::getOption('aviberry_storage_type') == 's3')
		$value = AVIBERRY_S3_HOST;
		
	return $value;
}

function aviberry_add_options_page() {
	require_once('tpl/options_page.php');
}

function aviberry_register_options() {
	// Register plugin options.
	register_setting('aviberry-options-group', 'aviberry_api_host');
	register_setting('aviberry-options-group', 'aviberry_api_key');
	register_setting('aviberry-options-group', 'aviberry_api_pass');
	register_setting('aviberry-options-group', 'aviberry_storage_type');
	register_setting('aviberry-options-group', 'aviberry_storage_user');
	register_setting('aviberry-options-group', 'aviberry_storage_pass');
	register_setting('aviberry-options-group', 'aviberry_storage_host');
	register_setting('aviberry-options-group', 'aviberry_storage_port');
	register_setting('aviberry-options-group', 'aviberry_storage_path');
	register_setting('aviberry-options-group', 'aviberry_display_tooltips');
	register_setting('aviberry-options-group', 'aviberry_use_player');
	register_setting('aviberry-options-group', 'aviberry_player_embedding_type');
	register_setting('aviberry-options-group', 'aviberry_player_width');
	register_setting('aviberry-options-group', 'aviberry_player_height');
}

function aviberry_media_row_actions($actions, $post) {
	// Next line from WordPress sources.
	$file_extension = strtolower(preg_replace('/^.*?\.(\w+)$/', '$1', get_attached_file($post->ID)));
	if (strpos(AVIBERRY_VIDEO_FILEXTS, "|$file_extension|") === false)
		return $actions; // If we don't know what is it, skip.
	
	$thumbnail_url = false;
	$attachment_url = wp_get_attachment_url($post->ID);
	$attached_file = get_attached_file($post->ID);
	if(!empty($attached_file) && file_exists(WP_CONTENT_DIR . '/uploads' . $attached_file . '.jpg') )
		$thumbnail_url = $attachment_url . '.jpg';
	
	//post is converting
	if (aviberryPlugin::getPostConversionId($post->ID))
		// Add "Cancel" action.
		if (aviberryPlugin::isInstallationCompleted())
			$actions['convert'] = 
				'<a class="aviberry-conversion-link" href="javascript:void(0)" ' 
					. 'post_id="'       . $post->ID                                      . '" '
					. 'filename="'      . basename($attachment_url)     . '" '
					. 'filelink="'      . $attachment_url               . '" '
					. 'conversion_id="' . aviberryPlugin::getPostConversionId($post->ID) . '" '
					. 'title="'         . aviberryPlugin::i18n('tooltipCancel')          . '" '
					. ($thumbnail_url ? 'thumbnail_url="'       . $thumbnail_url         . '" ' : '')
				. '>'
					. aviberryPlugin::i18n('cancel')
				. '</a>'
			;
		else
			$actions['convert'] = 
				  '<span class="aviberry-not-completed-installation"' 
					. 'title="' . aviberryPlugin::i18n('tooltipNci') . '" ' 
				  . '>' 
					. aviberryPlugin::i18n('cancel')
				. '</span>'
			;
	
	//post is NOT converting
	else
		// Add "Convert" action.
		if (aviberryPlugin::isInstallationCompleted())
			$actions['convert'] =
				'<a class="aviberry-conversion-link" '
					. 'href="javascript:void(0)" '
					. 'post_id="'  . $post->ID                                  . '" '
					. 'filename="' . basename($attachment_url) . '" '
					. 'filelink="' . $attachment_url           . '" '
					. 'title="'    . aviberryPlugin::i18n('tooltipConvert')     . '" '
					. ($thumbnail_url ? 'thumbnail_url="'       . $thumbnail_url         . '" ' : '')
				. '>'
					. aviberryPlugin::i18n('convert')
				. '</a>'
			;
		else
			$actions['convert'] =
				  '<span class="aviberry-not-completed-installation"'
					. 'title="' . aviberryPlugin::i18n('tooltipNci') . '" '
				  . '>'
					. aviberryPlugin::i18n('convert')
				. '</span>'
			;

	return $actions;
}
?>
