/**
 * "Aviberry" scope and functionality.
 */
function Aviberry() {
	// Running conversions.
	var postConversions = new Object();

	/**
	 * Returns conversion id by post id.
	 *  
	 * @param Number post_id
	 * @return Number
	 */
	var getConversionByPost = function(post_id) {
		return postConversions[post_id];
	};

	/**
	 * Returns post id by conversion id. Function is reverse to  
	 * getConversionByPost.
	 * 
	 * @param Number conversion_id
	 * @return Number 
	 */
	var getPostByConversion = function(conversion_id) {
		for (var post_id in postConversions)
			if (postConversions[post_id] == conversion_id)
				return post_id;
	};
	
	// RPC client of plugin API.
	var rpcPlugin = new rpc.ServiceProxy(
		aviberryPlugin.AVIBERRY_PLUGIN_API_URL, 
		{
			asynchronous:    false, // !!! 
			sanitize:        true,      
			protocol:        "JSON-RPC",
			methods: [ 
				"startPostConversion", 
				"finishPostConversion"
			]
		}
	);
	
	// RPC client of Aviberry API's proxy.
	var rpcOnline = new rpc.ServiceProxy(
		aviberryPlugin.AVIBERRY_PLUGIN_API_URL, 
		{
			asynchronous:    true,      
			sanitize:        true,      
			protocol:        "JSON-RPC",
			methods: [ 
				"startConversion",
				"cancelConversion",
				"getProgress"
			]
		}
	);
	
	// "Convert" action link for specified post.
	var linkConvertFile = function (post_id) {return jQuery(".aviberry-conversion-link[post_id=" + post_id + "]");};
	var progressPanel   = function (post_id) {return jQuery("#aviberry-conversion-progress-" + post_id);};
	var progressMessage = function (post_id) {return jQuery("#aviberry-conversion-progress-" + post_id + " span.aviberry-message");};
	var progressBar     = function (post_id) {return jQuery("#aviberry-conversion-progress-" + post_id + " div.aviberry-bar");};

	/**
	 *
	 */
	var getFormatByPreset = function (preset_id) {
		return jQuery('#aviberry_preset_id option[value=' + preset_id + ']').parent().attr('format_id');
	};
	
	// Dialog to select options and confirm start of conversion.
	var dlgStartPostConversion = jQuery("#dlg_start_post_conversion")
		.dialog({
			message:       "",   // Custom property.
			post_id:       null, // Custom property.
			filename:      null, // Custom property.
			conversion_id: null, // Custom property.
			format_id:     null, // Custom property.
			
			title:     "Aviberry Plug-In",
			autoOpen:  false,
			modal:     true,
			width:     400,
			resizable: false,
			
			open: function(event, ui) {
				// Set dialog message.
				jQuery(".message", this).html(
					jQuery(this).dialog("option", "message").replace(
						"{$filename}", 
						jQuery(this).dialog("option", "filename")
					)
				);
				
				if (jQuery(this).dialog("option", "conversion_id") == undefined)
					jQuery("#aviberry_preset_id").show();
				else
					jQuery("#aviberry_preset_id").hide();
				
				// Set button "OK" focused by default.
				var context = jQuery(this).parents(".ui-dialog");
				jQuery(":button:contains('Ok')", context).focus();
			},
			
			buttons: { 
				"Cancel": function() {
					jQuery(this).dialog("close");
				},
				"Ok": function() {
					jQuery(this).dialog("close");
				
					// Save selected preset id into dialog attribute.
					jQuery(this).dialog("option", "preset_id", jQuery("#aviberry_preset_id").val());
					jQuery(this).dialog("option", "format_id", getFormatByPreset(jQuery("#aviberry_preset_id").val()));
					
					if (jQuery(this).dialog("option", "conversion_id") == null) {
						// Start file conversion.
						startPostConversion(jQuery(this).dialog("option", "post_id"));
					} else
						// Cancel file conversion.
						cancelPostConversion(jQuery(this).dialog("option", "post_id"));
				}
			}
	});

	/**
	 * Handler to start file conversion.
	 * 
	 * @return Boolean
	 */
	var linkConvertFile_OnClick = function() {
		var filename      = jQuery(this).attr("filename");
		var post_id       = jQuery(this).attr("post_id");
		var conversion_id = jQuery(this).attr("conversion_id");
		
		if (conversion_id == undefined) {
			// Confirm to start file conversion.
			dlgStartPostConversion.dialog("option", "message", "Convert file \"{$filename}\" to format:");
			dlgStartPostConversion.dialog("option", "conversion_id", null); 
		} else {
			// Confirm to cancel file conversion.
			dlgStartPostConversion.dialog("option", "message", aviberryPlugin.i18n.cancelPostConversion);
			dlgStartPostConversion.dialog("option", "conversion_id", conversion_id); 
		}
		dlgStartPostConversion.dialog("option", "post_id",  post_id);
		dlgStartPostConversion.dialog("option", "filename", filename);
		dlgStartPostConversion.dialog("open");
		
		return false;
	};

	/**
	 * Alters WordPress' media table. There is no suitable hook in PHP to modify
	 * the table, so this is done by JS. Function also does actions to
	 * initialize certain data in the table. 
	 * 
	 * @return void
	 */
	var processMediaTable = function () {
		var table = jQuery("#the-list").parent();
		
		//
		// Add new column "Conversion progress".
		//
		
		// Append column headers on top and bottom of table.
		var th = 
			  '<th class="manage-column aviberry-column-conversion-progress" scope="col">' 
			+ aviberryPlugin.i18n.conversionProgress 
			+ '</th>';
		jQuery("thead > tr", table).append(th);
		jQuery("tfoot > tr", table).append(th);
		
		//
		// Init hash of running conversions.
		//
		
		// Run by all posts in table.
		var rows = jQuery("tbody > tr", table);
		for (var i = 0; i < rows.length; i++) {
			var post_id       = rows[i].id.substring(5);
			var conversion_id = linkConvertFile(post_id).attr("conversion_id");
			var thumbnail_url = linkConvertFile(post_id).attr("thumbnail_url");
	
			// At the end of each row append column cell to hold conversion progress.
			jQuery(rows[i]).append(
				  '<td class="aviberry-column-conversion-progress">'
					+ '<div id="aviberry-conversion-progress-' + post_id + '">'
						+ '<div class="aviberry-bar"></div>'
						+ '<span class="aviberry-message"></span>'
					+ '</div>'
				+ '</td>'
			);

			// Hide progress by default.
			progressPanel(post_id).hide();
			
			//if there is thumbnail then show it
			if(thumbnail_url){
				var img = jQuery(rows[i]).find(".column-icon img.attachment-80x60");
				if(img){
					img.removeAttr("width");
					img.attr("src", thumbnail_url);
				}
			}
			
			if (conversion_id) {
				// Init conversion on client side.
				postConversions[post_id] = conversion_id;
				// Update GUI.
				progressMessage(post_id).text(aviberryPlugin.i18n.startPostConversion);
				progressBar(post_id).progressbar("option", "value", 0);
				progressPanel(post_id).show();				
			}
		}
	};

	/**
	 * Formats time in human-readable string.
	 * 
	 * @param Number time
	 * @return String
	 */
	var formatTime = function (time) {
		if (time == 0)
			time = 0; // Do nothing. 
		else if (time < 10)
			time = aviberryPlugin.i18n.few_secs;
		else if (time < 60)
			time = aviberryPlugin.i18n.less_min;
		else {
			timeH = parseInt(time / (60 * 60));
			timeM = parseInt((time - timeH * 60 * 60) / 60);
			timeS = time - timeH * 60 * 60 - timeM * 60;
			time = ""
				+ (timeH ? timeH + " " + aviberryPlugin.i18n.h + " " : "")
				+ (timeM ? timeM + " " + aviberryPlugin.i18n.m + " " : "")
				+ (timeS ? timeS + " " + aviberryPlugin.i18n.s + " " : "");
		}
		
		return typeof time == "string" ? time.replace(/(^\s+)|(\s+$)/g, "") : time;  // trim() if string.
	};
	

	/**
	 * Does required actions after conversion of file post_id. Conversion can be 
	 * successfully or unsuccessfully (with error) complete, or canceled. After
	 * all this actions finishPostConversion is called.
	 * 
	 * @param Number post_id
	 * @return void
	 */
	var finishPostConversion = function (post_id) {
		try {
			// Synchronous call to cancel conversion on plugin's server side.
			rpcPlugin.finishPostConversion(post_id);
		} catch (e) {
			// Error.
			progressMessage(post_id).text(aviberryPlugin.i18n.epicFail + ": " + e.message);
			progressMessage(post_id).addClass('aviberry-fail');
		}
		
		// Whatever cancel conversion on plugin's client side.
		delete postConversions[post_id]; 
		linkConvertFile(post_id).removeAttr("conversion_id");

		//
		// Update GUI.
		//
		
		linkConvertFile(post_id).html(aviberryPlugin.i18n.convert);
		linkConvertFile(post_id).attr("title", aviberryPlugin.i18n.tooltipConvert);
		updateTooltips();

		progressPanel(post_id);
	};
		
	/**
	 * Cancels conversion of file post_id.
	 * 
	 * @param Number post_id
	 * @return void
	 */
	var cancelPostConversion = function (post_id) {
		// First, get conversion id before local cancel.
		var conversion_id = getConversionByPost(post_id);
		
		// Cancel locally.
		finishPostConversion(post_id);
		
		// Update GUI.
		progressBar(post_id).progressbar("option", "value", 0);
		progressMessage(post_id).text(aviberryPlugin.i18n.progressCanceling);

		// Cancel remotely.
		rpcOnline.cancelConversion({
			params: {
				"conversion_id": conversion_id
			},
			onSuccess: function (response) {
				progressMessage(post_id).text(aviberryPlugin.i18n.conversionCanceled);
			},
			onException: function(error) {
				// Error.
				progressMessage(post_id).text(aviberryPlugin.i18n.epicFail + ": " + e.message);
				progressMessage(post_id).addClass('aviberry-fail');
			}
		});
	};
	
	/**
	 * Starts conversion of file post_id. 
	 * 
	 * @param Number post_id 
	 * @return void
	 */
	var startPostConversion = function (post_id) {
		var filename  = linkConvertFile(post_id).attr("filename");
		var filelink  = linkConvertFile(post_id).attr("filelink");
		var format_id = dlgStartPostConversion.dialog("option", "format_id");
		var preset_id = dlgStartPostConversion.dialog("option", "preset_id");		
		var timestamp = new Date();
		timestamp = parseInt(timestamp.getTime() / 1000);

		
		// Remove file extension. 
		filename = filename.substr(0, filename.lastIndexOf("."));

		//
		// Update GUI.
		//
		
		progressMessage(post_id).removeClass('aviberry-success');
		progressMessage(post_id).removeClass('aviberry-fail');
		
		progressMessage(post_id).text(aviberryPlugin.i18n.initPostConversion);
		progressBar(post_id).progressbar("option", "value", 0);
		progressPanel(post_id).fadeIn('slow');
		
		//
		// Call API.
		//
		
		rpcOnline.startConversion({
			params: {
				"source_url":    filelink,
				"target_url":    aviberryPlugin.storageUrl + filename + "_" + timestamp,
				"preset": {
					"format_id": format_id,
					"preset_id": preset_id
				},
				"title": filename
			},
			onSuccess: function (response) {
				var conversion_id = response;
				
				try {
					// Synchronous call to start conversion on plugin's server side.
					rpcPlugin.startPostConversion(post_id, conversion_id);
					
					// If all is ok (no exception), start conversion on plugin's client side.
					postConversions[post_id] = conversion_id;
					linkConvertFile(post_id).attr("conversion_id", conversion_id);
					
					//
					// Update GUI.
					//
					
					linkConvertFile(post_id).html(aviberryPlugin.i18n.cancel);
					linkConvertFile(post_id).attr("title", aviberryPlugin.i18n.tooltipCancel);
					updateTooltips();
					
					progressMessage(post_id).text(aviberryPlugin.i18n.startPostConversion);
					
				} catch (e) {
					// Error.
					progressMessage(post_id).text(aviberryPlugin.i18n.epicFail + ": " + e.message);
					progressMessage(post_id).addClass('aviberry-fail');
				}
			},
			onException: function(e) {
				// Error.
				progressMessage(post_id).text(aviberryPlugin.i18n.epicFail + ": " + e.message);
				progressMessage(post_id).addClass('aviberry-fail');
				return true;
			}
		});
	};
	
	/**
	 * Reactivates all tooltips.
	 * 
	 * @return void
	 */
	var updateTooltips = function () {
		if (aviberryPlugin.displayTooltips) {
			jQuery(".aviberry-conversion-link[title]").tooltip({showURL: false});
			jQuery(".aviberry-not-completed-installation[title]").tooltip({showURL: false});
		}
	};
	
	/**
	 * Updates progress of conversions.
	 * 
	 * @return void
	 */
	var watchPostConversions = function () {
		var sids = [];
		// Run throw active conversions.
		for (var post_id in postConversions){
				var conversion_id = getConversionByPost(post_id);
				if (conversion_id)
					sids.push(conversion_id);
		}
		
		//if there are sids then get progress from Aviberry.
		if(sids.length > 0)							
			rpcOnline.getProgress({
				params: {
					"conversion_id": sids
				},
				onSuccess: function(response) {
					
					for (var i in response) {							
						var conversion_id = response[i].conversion_id;
						var post_id       = getPostByConversion(conversion_id);
						if (typeof post_id == "undefined")
							continue;
						
						// Process progress.
						switch (response[i].status) {
							case "notfound":
								progressBar(post_id).progressbar("option", "value", 100);
								progressMessage(post_id).text("Not found");
		
								finishPostConversion(post_id);
								
								break;
								
							case "queued":
								progressBar(post_id).progressbar("option", "value", 0);
								progressMessage(post_id).text(aviberryPlugin.i18n.progressQueued);
								
								break;
								
							case "downloading":
								progressBar(post_id).progressbar("option", "value", response[i].percent);
								progressMessage(post_id).text(aviberryPlugin.i18n.progressDownloading + " " + response[i].percent + "%");
								
								break;
								
							case "converting":
								var timeLeft = aviberryPlugin.i18n.timeLeft.replace("{$time}", formatTime(response[i].remaining_time)); 
								
								progressBar(post_id).progressbar("option", "value", response[i].percent);
								progressMessage(post_id).text(
									  aviberryPlugin.i18n.progressConverting + " " 
									+ timeLeft.replace(/^.{1}/, " " + timeLeft.charAt(0).toLocaleUpperCase()) // First char to upper case.
								);
								
								break;
								
							case "uploading":
								progressBar(post_id).progressbar("option", "value", response[i].percent);
								progressMessage(post_id).text(aviberryPlugin.i18n.progressUploading + " " + response[i].percent + "%");
								
								break;
								
							case "finished":
								progressBar(post_id).progressbar("option", "value", 100);

								// No error.
								if (response[i].error_code == 0) {
									
									var message = aviberryPlugin.i18n.epicWin;
									
									if(	aviberryPlugin.storageType == 'wp_media_lib_ftp' ||
										aviberryPlugin.storageType == 'wp_media_lib_ftps')
										message += '. ' + aviberryPlugin.i18n.pleaseReloadThePage;

									progressMessage(post_id).text(message);
									progressMessage(post_id).addClass('aviberry-success');
								// Error.
								} else {
									progressMessage(post_id).text(aviberryPlugin.i18n.epicFail + ": " + response[i].error_message);
									progressMessage(post_id).addClass('aviberry-fail');
								}
		
								finishPostConversion(post_id);
								
								break;
								
							case "canceled":
								progressBar(post_id).progressbar("option", "value", 100);
								progressMessage(post_id).text(aviberryPlugin.i18n.conversionCanceled);
		
								finishPostConversion(post_id);
								
								break;
								
							default:
								
								break;
						}
					}
					setTimeout(watchPostConversions, aviberryPlugin.AVIBERRY_WATCH_TIMEOUT);
				},
				onException: function(error) {
					alert(error.message);
					setTimeout(watchPostConversions, aviberryPlugin.AVIBERRY_WATCH_TIMEOUT);
				}
			});
		else
			setTimeout(watchPostConversions, aviberryPlugin.AVIBERRY_WATCH_TIMEOUT);
	};
	
	// Assign handler to "Convert" action.
	jQuery(".aviberry-conversion-link").click(linkConvertFile_OnClick);
	
	// Prepare tooltips.
	updateTooltips();
	
	// Process existent table by JS because there is no appropriate hooks in PHP.
	processMediaTable();
	
	// Watch started file conversions.
	watchPostConversions();
}

jQuery(document).ready(function () {
	var aviberry = new Aviberry();
});
