/**
 * "Aviberry" scope and functionality.
 */ 
function Aviberry() {
	// Radio group.
	var radioFileStorageType = function() {return jQuery(":radio[name=aviberry_storage_type]");}; 
	var oldFileStorageTypeValue = radioFileStorageType().filter(':checked').val(); // Store initially old value. 
	
	// Lables.
	var lblFileStorageUser = function() {return jQuery("label[for=aviberry_storage_user]");};
	var lblFileStoragePass = function() {return jQuery("label[for=aviberry_storage_pass]");};
	var lblFileStorageHost = function() {return jQuery("label[for=aviberry_storage_host]");};
	var lblFileStoragePort = function() {return jQuery("label[for=aviberry_storage_port]");};
	var lblFileStoragePath = function() {return jQuery("label[for=aviberry_storage_path]");};

	// Text boxes.
	var txtFileStorageUser = function() {return jQuery("input[name=aviberry_storage_user]");};
	var txtFileStoragePass = function() {return jQuery("input[name=aviberry_storage_pass]");};
	var txtFileStorageHost = function() {return jQuery("input[name=aviberry_storage_host]");};
	var txtFileStoragePort = function() {return jQuery("input[name=aviberry_storage_port]");};
	var txtFileStoragePath = function() {return jQuery("input[name=aviberry_storage_path]");};

	// Examples.
	var lblFileStorageHostExample = function() {return jQuery(".aviberry_param_example", txtFileStorageHost().parent());};
	var lblFileStoragePortExample = function() {return jQuery(".aviberry_param_example", txtFileStoragePort().parent());};
	var lblFileStoragePathExample = function() {return jQuery(".aviberry_param_example", txtFileStoragePath().parent());};
	
	// Dialog.
	var dlgFileStorageChangeConfirm = jQuery("<div></div>")
		.dialog({
			message:   "All info about current file storage will be reseted. Continue?", // Custom property.
			title:     "Aviberry Plug-In",
			autoOpen:  false,
			modal:     true,
			resizable: false,
			open:      function(event, ui) {
				dlgFileStorageChangeConfirm.html(
					dlgFileStorageChangeConfirm.dialog('option', 'message')
				);
				
				var context = dlgFileStorageChangeConfirm.parents(".ui-dialog");
				jQuery(":button:contains('" + aviberryPlugin.i18n.ok + "')", context).focus();
			},
			buttons:   { 
				"Cancel": function() { 
					jQuery(this).dialog("close");

					// Restore old value.
					radioFileStorageType().filter('[value=' + oldFileStorageTypeValue + ']').attr('checked', true);
				},
				"Ok": function() {
					jQuery(this).dialog("close");
					
					changeFileStorage();
					
					// Store old value.
					oldFileStorageTypeValue = radioFileStorageType().filter(':checked').val(); 
				}
			}
		});
	
	/**
	 * Handler for action "Change file storage".
	 * 
	 * @return void
	 */
	var radioFileStorageType_OnClick = function() {
		if (isSpecifiedFileStorageInfo())
			dlgFileStorageChangeConfirm.dialog('open');
		else
			changeFileStorage();
	};
	
	/**
	 * Changes file storage (GUI).
	 */
	var changeFileStorage = function(use_options) {
		lblFileStorageUser().html(aviberryPlugin.i18n.user); 
		lblFileStoragePass().html(aviberryPlugin.i18n.pass);
		lblFileStoragePath().html(aviberryPlugin.i18n.path);

		if (use_options) {
			radioFileStorageType().filter('[value=' + aviberryPlugin.storageType + ']').attr('checked', true);
			txtFileStorageUser().val(aviberryPlugin.storageUser); 
			txtFileStoragePass().val(aviberryPlugin.storagePass);
			txtFileStorageHost().val(aviberryPlugin.storageHost);
			txtFileStoragePort().val(aviberryPlugin.storagePort);
			txtFileStoragePath().val(aviberryPlugin.storagePath);
		} else {
			txtFileStorageUser().val(""); 
			txtFileStoragePass().val("");
			txtFileStorageHost().val("");
			txtFileStoragePort().val("");
			txtFileStoragePath().val("");
		}

		txtFileStorageHost().attr("disabled", false);		
		txtFileStoragePort().parents("tr").show();
		
		var sFileStorageType = radioFileStorageType().filter(':checked').val();		
		
		// Examples.
		switch (sFileStorageType) {			
			case "wp_media_lib_ftp":
				lblFileStorageHostExample().html("example.com");
				lblFileStoragePortExample().html("21");
				lblFileStoragePath().html(aviberryPlugin.i18n.labelPathWordpressMediaLibrary);
				lblFileStoragePathExample().html(aviberryPlugin.i18n.examplePathToWordpressMediaLibrary);
				
				break;
			case "wp_media_lib_ftps":				
				lblFileStorageHostExample().html("example.com");
				lblFileStoragePortExample().html("22");
				lblFileStoragePath().html(aviberryPlugin.i18n.labelPathWordpressMediaLibrary);
				lblFileStoragePathExample().html(aviberryPlugin.i18n.examplePathToWordpressMediaLibrary);
				
				break;
			case "ftp":
				lblFileStorageHostExample().html("example.com");
				lblFileStoragePortExample().html("21");
				lblFileStoragePath().html(aviberryPlugin.i18n.labelStoragePath);
				lblFileStoragePathExample().html(aviberryPlugin.i18n.examplePath);
			
				break;
				
			case "ftps":
				lblFileStorageHostExample().html("example.com");
				lblFileStoragePortExample().html("22");
				lblFileStoragePath().html(aviberryPlugin.i18n.labelStoragePath);
				lblFileStoragePathExample().html(aviberryPlugin.i18n.examplePath);
				
				break;
				
			case "s3":
				lblFileStorageUser().html(aviberryPlugin.i18n.awsKey); 
				lblFileStoragePass().html(aviberryPlugin.i18n.awsPass);
				lblFileStoragePath().html(aviberryPlugin.i18n.awsBucket);
				
				txtFileStorageHost().val(aviberryPlugin.AVIBERRY_S3_HOST);
				
				txtFileStorageHost().attr("disabled", true);
				txtFileStoragePort().parents("tr").hide();
				
				lblFileStorageHostExample().html(aviberryPlugin.AVIBERRY_S3_HOST);
				lblFileStoragePortExample().html("");
				lblFileStoragePath().html(aviberryPlugin.i18n.labelStoragePath);
				lblFileStoragePathExample().html(aviberryPlugin.i18n.exampleBacket);
				
				break;
		}
	};
	
	/**
	 * Returns whether all required info about storage is filled.
	 * 
	 * @return Boolean
	 */
	var isSpecifiedFileStorageInfo = function() {
		var sFileStorageType = radioFileStorageType().filter(':checked').val();
		
		return Boolean(
			   txtFileStorageUser().val() 
			|| txtFileStoragePass().val()
			|| (txtFileStorageHost().val() && txtFileStorageHost().val() != aviberryPlugin.AVIBERRY_S3_HOST) // Ignore host for "S3".
			|| txtFileStoragePort().val()
			|| txtFileStoragePath().val()
		);
	};
	
	/**
	 * Reactivates all tooltips.
	 * 
	 * @return void
	 */
	var updateTooltips = function () {
		if (aviberryPlugin.displayTooltips) {
			jQuery("form input[title]").tooltip({showURL: false});
			jQuery("form label[title]").tooltip({showURL: false});
		}
	};

	// Assign handler to radio for selection of storage type.
	radioFileStorageType().click(radioFileStorageType_OnClick);

	// Prepare tooltips.
	updateTooltips();
	
	// Setup initially GUI for current options of plugin.
	changeFileStorage(true);
}

jQuery(document).ready(function() {
	var aviberry = new Aviberry();
});
