<?php
// Constants
define('AVIBERRY_PLUGIN_DIR',      basename(realpath(dirname(__FILE__) . '/../../')));
define('AVIBERRY_PLUGIN_ABSPATH',  WP_PLUGIN_DIR . '/' . AVIBERRY_PLUGIN_DIR . '/');
define('AVIBERRY_PLUGIN_URL',      WP_PLUGIN_URL . '/' . AVIBERRY_PLUGIN_DIR . '/');
define('AVIBERRY_VIDEO_FILEXTS',   '|3gp|3gp2|avi|flv|mov|mp4|mpeg|mpg|wmv|webm|');
define('AVIBERRY_S3_HOST',         's3.amazonaws.com');
define('AVIBERRY_PLUGIN_API_URL',  AVIBERRY_PLUGIN_URL . 'api/');

define('AVIBERRY_API_HOST', 'www.aviberry.com');
define('AVIBERRY_API_VERSION', 'v1.1');
define('AVIBERRY_API_PROTOCOL', 'json'); // json|xml.
define('AVIBERRY_API_URL_AUTHORIZED',  'http://{$api_key}:{$api_pass}@{$api_host}/api/' . AVIBERRY_API_VERSION . '/' . AVIBERRY_API_PROTOCOL . '/');

//Connection timeout for ApiClient. Seconds
define('AVIBERRY_API_CLIENT_CONNECTTIMEOUT', 30);

define('AVIBERRY_WATCH_TIMEOUT',   5000);

// Defaults
define('AVIBERRY_STORAGE_TYPE',          'ftp');
define('AVIBERRY_USE_PLAYER',            false);
define('AVIBERRY_PLAYER_WIDTH',          400);
define('AVIBERRY_PLAYER_HEIGHT',         300);
define('AVIBERRY_PLAYER_EMBEDDING_TYPE', 'javascript');

class aviberryException extends Exception {}

class aviberryPlugin {
	static private $_isInstallationCompleted = null;
	static public $_i18n = null;
	
	static public function init() {
		self::$_i18n = array (
			'ok'									=> __('Ok'), 
			'cancel'								=> __('Cancel'), 
			'convert'								=> __('Convert'), 
			'user'									=> __('User'), 
			'pass'									=> __('Password'), 
			'path'									=> __('Path'), 
			'awsKey'								=> __('AWS key'), 
			'awsPass'								=> __('AWS password'), 
			'awsBucket'								=> __('AWS bucket'), 
			'conversionProgress'					=> __('Conversion<br/>progress'), 
			'cancelPostConversion'					=> __('Cancel conversion of \"{$filename}\"?'), // Escape " for JS 
			'startPostConversion'					=> __('Please wait...'), 
			'initPostConversion'					=> __('Connecting to service...'), 
			'h'										=> __('h.'), 
			'm'										=> __('min.'), 
			's'										=> __('sec.'), 
			'less_min'								=> __('less than a minute'), 
			'few_secs'								=> __('a few seconds'), 
			'tooltipConvert'						=> __('Convert file with Aviberry'), 
			'tooltipCancel'							=> __('Cancel file conversion'), 
			'tooltipNci'							=> __('Please specify your Aviberry API key and password on the plugin\'s settings page.'), // Not completed installation. 
			'progressDownloading'					=> __('Downloading...'), 
			'progressUploading'						=> __('Uploading...'), 
			'progressQueued'						=> __('Queued...'), 
			'progressConverting'					=> __('Converting...'), 
			'progressCanceling'						=> __('Canceling...'), 
			'timeLeft'								=> __('{$time} left'), 
			'epicWin'								=> __('Successfully completed'),
			'pleaseReloadThePage'					=> __('Please reload webpage to see the converted file'),
			'epicFail'								=> __('Unable to convert the file'), 
			'examplePath'							=> __('path/to/target/dir/'), 
			'examplePathToWordpressMediaLibrary'	=> __('path/to/WordPress/wp-content/uploads/'), 
			'exampleBacket'							=> __('bucket_name/path/to/target/dir/'), 
			'labelStoragePath'						=> __('Path'), 
			'labelPathWordpressMediaLibrary'		=> __('Path to WordPress media library'), 
			'conversionCanceled'					=> __('Canceled'),
		);
	}
	
	static public function i18n($key) {
		if (is_null(self::$_i18n))
			self::init();
		
		if (!array_key_exists($key, self::$_i18n))
			throw new aviberryException(sprintf('Unknown internationalization key "%s".', $key));
		
		return self::$_i18n[$key];
	}
	
	/**
	 * Returns "true" if required info for plugin is filled.
	 * 
	 * @return bool
	 */
	static public function isInstallationCompleted() {
		if (is_null(self::$_isInstallationCompleted))
			self::$_isInstallationCompleted = 
				   self::getOption('aviberry_api_key')
				&& self::getOption('aviberry_api_pass');
				
		return self::$_isInstallationCompleted;
	}
	
	/**
	 * Compares Wordpress version with a specified one.
	 *
	 * @return mixed
	 */
	static public function isWordpressVersion($operator, $version) {
		global $wp_version;
		
		return version_compare($wp_version, $version, $operator);
	}
	
	/**
	 * Returns "true" if info about storage is filled.
	 * 
	 * @return bool
	 */
	static public function isFileStorageSpecified() {
		return 
			   self::getOption('aviberry_storage_user')
			&& self::getOption('aviberry_storage_pass')
			&& self::getOption('aviberry_storage_host');
	}
	
	/**
	 * Returns plugin option.
	 * 
	 * @return string
	 */
	static public function getOption($option) {
		$default = false;
		
		$constant = strtoupper($option);
		if (defined($constant))
			$default = constant($constant);
			
		return get_option($option, $default);
	}
	
	/**
	 * Built and returns storage URL.
	 *
	 * @return string
	 */
	static public function getStorageUrl() {
		$result = '';
		
		$type = self::getOption('aviberry_storage_type');
		$host = self::getOption('aviberry_storage_host');
		$user = self::getOption('aviberry_storage_user');
		$pass = self::getOption('aviberry_storage_pass');
		$port = self::getOption('aviberry_storage_port');
		
		$bucket = '';
		
		$path   = self::getOption('aviberry_storage_path');
		
		// Normalize path.
		$path = array_diff(explode('/', $path), array(''));
		$path = implode('/', $path);
		
		$user = rawurlencode($user);
		$pass = rawurlencode($pass);
		
		//Determine scheme
		switch ($type) {
			case 'wp_media_lib_ftp': 
				$scheme = 'ftp://'; 
				break;
			
			case 'wp_media_lib_ftps': 
				$scheme = 'ftps://';
				break;
			
			case 'ftp':  
				$scheme = 'ftp://'; 
				break;
				
			case 'ftps': 
				$scheme = 'ftps://';
				break;
				
			case 's3':  
				$scheme = 'http://';
				break;
				
			default:     
				$scheme = 'http://';
				break;
		}
		
		//Determine specific URL parameters
		switch ($type) {
			case 'wp_media_lib_ftps':
			case 'wp_media_lib_ftp': 				
				/**
				* path for media library must be added
				* with wordpress upload subdir
				*/
				$upload_dir = wp_upload_dir();				
				$path .= $upload_dir['subdir'];				
				
				break;
				
			case 's3':  
				$pos = strpos($path, '/');
				if ($pos !== false) {
					$bucket = substr($path, 0, $pos);
					$path   = substr($path, $pos + 1);
				} else {
					$bucket = $path;
					$path   = '';
				}
				
				break;
		}
		
		$result =
			  $scheme
			. ($user ? ($user . ($pass ? ':' . $pass : '')) . '@' : '')
			. ($bucket ? $bucket . '.' : '')
			. $host	. ($port ? ':' . $port : '') . '/'
			. ($path ? $path . '/' : '');
			
		return $result;
	}
	
	static public function startPostConversion($post_id, $conversion_id) {
		add_post_meta($post_id, 'aviberry_conversion_id', $conversion_id, true)
			|| update_post_meta($post_id, 'aviberry_conversion_id', $conversion_id);
	}
	
	static public function finishPostConversion($post_id) {
		delete_post_meta($post_id, 'aviberry_conversion_id');
	}
	
	static public function getPostConversionId($post_id) {
		return get_post_meta($post_id, 'aviberry_conversion_id', true);
	}
}
?>