<?php
//
// Данный файл при изменении всегда должен быть синхронизирован с аналогичным на ферме.
//
// Назначение этого файла: 
// 		обеспечивание внутренних вызовов АПИ между серверами;
// 		трансляция исключительных ситуаций АПИ между серверами;
//		собственные генерируемые исключения должны удовлетворять архитерктуре искоючений АПИ.
//

/*
 Copyright 2011 Aviberry 
 */

/**
 * The object of this class are generic jsonRPC 1.0 clients
 * http://json-rpc.org/wiki/specification
 */
class ApiClient {	
	 
	/**
	 * Количество попыток вызвать curl
	 *
	 * @var integer
	 */
	public static $retries = 3;

	/**
	 * Debug state
	 *
	 * @var integer
	 */
	public $connectTimeout = AVIBERRY_API_CLIENT_CONNECTTIMEOUT;

	/**
	 * Debug state
	 *
	 * @var boolean
	 */
	public $debug;

	/**
	 * The server URL
	 *
	 * @var string
	 */
	private $url;
	/**
	 * The request id
	 *
	 * @var integer
	 */
	private $id;
	/**
	 * If true, notifications are performed instead of requests
	 *
	 * @var boolean
	 */
	private $notification = false;

	/**
	 * Takes the connection parameters
	 *
	 * @param string $url
	 * @param boolean $debug
	 */
	public function __construct($url, $debug = false) {
		
		// server URL
		$this->url = $url;
		// proxy
		empty($proxy) ? $this->proxy = '' : $this->proxy = $proxy;
		// debug state
		empty($debug) ? $this->debug = false : $this->debug = true;
		// message id
		$this->id = 1;
	}

	/**
	 * Performs a jsonRCP request and gets the results as an array
	 *
	 * @param string $method
	 * @param array $params
	 * @return array
	 */
	public function __call($method, $params) {		
		
		$time["1 start call"] = microtime(true);
		
		$params = $params[0];
		// check
		if (!is_scalar($method))
			throw new InternalError_ApiException('API Client: Method name has no scalar value.');

		$currentId = $this->id;
		// prepares the request
		$request = array(
			'version' => '1.1',
			'method'  => $method,
			'id'      => $currentId,
			'params'  => $params
		);
		$request = json_encode($request);
		$this->debug && $this->debug.='***** Request *****'."\n".$request."\n".'***** End Of request *****'."\n\n";
		//return;

		$time["before curl"] = microtime(true);
		// performs the HTTP POST
		$attempt = 0;
		$r = "";
		while (true) {
			$attempt++;

			$curl = curl_init($this->url);
				curl_setopt_array($curl, array(
				CURLOPT_FOLLOWLOCATION => true,
				CURLOPT_RETURNTRANSFER => true,
				CURLOPT_POST => true,
				CURLOPT_POSTFIELDS => $request,
				CURLOPT_VERBOSE => (int)$this->debug,
				CURLOPT_CONNECTTIMEOUT => $this->connectTimeout, //The number of seconds to wait while trying to connect. Use 0 to wait indefinitely.
				CURLOPT_HTTPHEADER => array('Content-type: application/json')
			));

			$r = curl_exec($curl);
			if ($error = curl_error($curl)) {
				if (!self::_exponentialBackoff($attempt, self::$retries))
					throw new ProtocolError_ApiException('API Client: ' . curl_error($curl));
					
				continue;
			}
			break;
		}
		$time["after curl"] = microtime(true);
		
		$this->debug && $this->debug.='***** Server response *****'."\n".$r.'***** End of server response *****'."\n";
		
		// Результат возвращаем именно как ассоциативный массив. См. документацию.
		$response = json_decode(trim($r), true);
		
		$this->debug && $this->debug.= print_r($time, true)."\n";
		
		// Если получаем ошибку, то просто возбуждаем исключение на клиентской стороне.		
		if (isset($response['error']))			
			throw new ApiException($response['error']['message'], $response['error']['code']);

		// Далее идут системные ошибки, которые никогда не возникнут, если
		// все идет по плану.		 
		if ($response['id'] != $currentId) {
			throw new ProtocolError_ApiException('API Client: Incorrect response id (' 
				.   'request id: ' . $currentId 
				. ', response id: ' . $response['id']
				. ', method response: ' . print_r($response, true)
				. ', protocol response: ' . print_r($r, true)
			. ')');
		}

		if (!isset($response['result']))
			throw new ProtocolError_ApiException('API Client: Request error.');
		
		return $response['result'];
	}
	
	protected static function _exponentialBackoff($current, $max) {
		if ($current <= $max) {
			$delay = (int)(pow(2, $current) * 100000);
			usleep($delay);
			return true;
		}
		return false;
	}
}
?>