<?php

class ApiException extends Exception {}

//
// Protocol Exceptions
//

// The error-codes -32768 .. -32000 (inclusive) are reserved for pre-defined errors.
// Any error-code within this range not defined explicitly below is reserved for future use.

// Invalid JSON. An error occurred on the server while parsing the JSON text.
class ParseError_ApiException extends ApiException {
	function __construct() {parent::__construct('Parse error.', -32700);}
}
// The received JSON is not a valid JSON-RPC Request.
class InvalidRequest_ApiException extends ApiException {
	function __construct($message = '') {
		if ($message)
			parent::__construct(sprintf('Invalid Request. %s', $message), -32600);
		else
			parent::__construct('Invalid Request.', -32600);
	}
}
// The requested remote-procedure does not exist / is not available.
class MethodNotFound_ApiException extends ApiException {
	function __construct($method = null) {
		if ($method)
			parent::__construct(sprintf('Method "%s" not found.', $method), -32601);
		else
			parent::__construct('Method not found.', -32601);
	}
}
// Invalid method parameters.
class InvalidParams_ApiException extends ApiException {
	function __construct() {parent::__construct('Invalid params.', -32602);}
}

// -32099..-32000 Server error. Reserved for implementation-defined server-errors.
// User defined errors are unsigned integers.

// Internal protocol error.
class ProtocolError_ApiException extends ApiException {
	function __construct($e = null) {
		if (is_object($e))
			parent::__construct(sprintf('Protocol error: %s', $e->getMessage()), -32000);
		elseif (is_string($e))
			parent::__construct(sprintf('Protocol error: %s', $e), -32000);
		else
			parent::__construct('Protocol error.', -32000);
	}
}

//
// Application Exceptions
//

// Internal application error.
class InternalError_ApiException extends ApiException {
	function __construct($e = null) {		
		if (is_object($e) && $e->getMessage())
			parent::__construct($e->getMessage(), 32000);
		elseif (is_string($e) && !empty($e))
			parent::__construct($e, 32000);
		else
			parent::__construct('Internal error.', 32000);
	}
}
class UnauthorizedAccess_ApiException extends ApiException {
	function __construct() {parent::__construct('Unauthorized access.', 1);}
}
class InvalidParamValue_ApiException extends ApiException {
	function __construct($message = '') {
		if ($message)
			parent::__construct($message, 2);
		else
			parent::__construct('Invalid value of parameter.', 2);
	}
}
class InactiveAccount_ApiException extends ApiException {
	function __construct() {parent::__construct('Inactive account.', 3);}
}
class ExceededLimit_ApiException extends ApiException {
	function __construct() {parent::__construct('Exceeded limit.', 4);}
}
class ExceededTraffic_ApiException extends ApiException {
	function __construct() {parent::__construct('Exceeded traffic.', 5);}
}
class InvalidConversionDirection_ApiException extends ApiException {
	function __construct($message = '') {
		if ($message)
			parent::__construct(sprintf('Invalid conversion direction. %s', $message), 6);
		else
			parent::__construct('Invalid conversion direction.', 6);
	}
}
class NotExistentFile_ApiException extends ApiException {
	function __construct($param) {parent::__construct(sprintf('File "%s" does not exist.', $param), 7);}
}
class FileAlreadyExists_ApiException extends ApiException {
	function __construct($param) {parent::__construct(sprintf('File "%s" already exists.', $param), 8);}
}
class AuthorizationRequired_ApiException extends ApiException {
	function __construct($param) {parent::__construct(sprintf('Access to "%s" denied. Authorization required.', $param), 9);}
}
class NotValidUserOrPassword_ApiException extends ApiException {
	function __construct($param) {parent::__construct(sprintf('Invalid login or password. Can\'t access "%s".', $param), 10);}
}
class CallbackError_ApiException extends ApiException {
	function __construct($message) {parent::__construct('Callback Error: ' . $message, 11);}
}
class DownloadError_ApiException extends ApiException {
	function __construct($message) {parent::__construct('Download Error: ' . $message, 12);}
}
class ConverterError_ApiException extends ApiException {
	function __construct($message) {parent::__construct('Converter Error: ' . $message, 13);}
}
class UploadError_ApiException extends ApiException {
	function __construct($message) {parent::__construct('Upload Error: ' . $message, 14);}
}
class UnknownAdditionalParam_ApiException extends ApiException {
	function __construct($param) {parent::__construct('Unknown additional param: ' . $param, 15);}
}
class UnknownFileSize_ApiException extends ApiException {
	function __construct($param) {parent::__construct(sprintf('Can\'t determine file size for "%s".', $param), 16);}
}
class ExceddedMaxFileSize_ApiException extends ApiException {
	function __construct($param) {parent::__construct(sprintf('File size for "%s" exceeds allowed limit.', $param), 17);}
}

?>