<?php
/**
 * Aviberry Plug-In settings administration panel.
 *
 * @package aviberryPlugin
 */
?>
<div class="wrap">
	<?php screen_icon(); ?>
	<h2><?php _e('Aviberry Plug-In Settings'); ?></h2>
	
	<form action="options.php" method="post" />
		<?php if (aviberryPlugin::isWordpressVersion('<', '2.7')): ?>
			<?php wp_nonce_field('update-options'); ?>
			<input type="hidden" name="action" value="update" />
			<input type="hidden" name="page_options" value="aviberry_api_key,aviberry_api_pass" />
		<?php else: ?>
			<?php  settings_fields('aviberry-options-group'); ?>
		<?php endif; ?>
		
		<h3><?php _e('Aviberry Member'); ?></h3>
		<p>
			<?php if (!aviberryPlugin::isInstallationCompleted()): ?>
			Fill listed below Aviberry's member info. If you are not Aviberry member, 
			please feel free to register at Aviberry's <a href="http://www.aviberry.com/register/">registration page</a>
			and get API key at "Account" tab after sign in. Until you do this all plugin actions 
			will be don't accessed and <span class="aviberry-not-completed-installation">highlighted</span>.
			<?php endif; ?>
		</p>

		<table class="form-table">
			<tbody>
				<tr valign="top">
					<th scope="row"><label for="aviberry_api_host"><?php _e('API host'); ?></label></th>
					<td><input type="text" class="regular-text" id="aviberry_api_host" name="aviberry_api_host" value="<?php echo aviberryPlugin::getOption('aviberry_api_host'); ?>" title="<?php _e('www.aviberry.com by default'); ?>" /></td>
				</tr>
				<tr valign="top">
					<th scope="row"><label for="aviberry_api_key"><?php _e('API key'); ?></label></th>
					<td><input type="text" class="regular-text" id="aviberry_api_key" name="aviberry_api_key" value="<?php form_option("aviberry_api_key"); ?>" title="<?php _e('API key of Aviberry\'s member. Get it on your account tab at http://www.aviberry.com/accounts/'); ?>" /></td>
				</tr>
				<tr valign="top">
					<th scope="row"><label for="aviberry_api_pass"><?php _e('API pass'); ?></label></th>
					<td><input type="text" class="regular-text" id="aviberry_api_pass" name="aviberry_api_pass" value="<?php form_option("aviberry_api_pass"); ?>" title="<?php _e('API pass of Aviberry\'s member. Get it on your account tab at http://www.aviberry.com/accounts/'); ?>" /></td>
				</tr>
			</tbody>
		</table>
		<br/>
		
		<h3><?php _e('File Storage'); ?></h3>
		<p>
			<?php if (!aviberryPlugin::isFileStorageSpecified()): ?>
			You should select a storage type for your converted files and fill info about it.
			<?php endif; ?>
		</p>
		<table class="form-table">
			<tr valign="top">
				<th scope="row"><label for="aviberry_storage_type"><?php _e('Type'); ?></label></th>
				<td>
					<?php
					$storage_types = array(						
						'wp_media_lib_ftp' => array(
							'caption'     => 'Media library (FTP)',
							'description' => __('Wordpress media library via FTP')
						),
						'wp_media_lib_ftps' => array(
							'caption'     => 'Media library (FTPS)',
							'description' => __('Wordpress media library via FTPS')
						),
						'ftp' => array(
							'caption'     => 'FTP',
							'description' => __('File Transfer Protocol')
						),
						'ftps' => array(
							'caption'     => 'FTPS',
							'description' => __('File Transfer Protocol + SSL')
						),
					    's3' => array(
							'caption'     => 'Amazon S3',
							'description' => __('Amazon\'s Simple Storage Service')
						)
					);
					$current_storage_type = aviberryPlugin::getOption('aviberry_storage_type'); 
					 
					foreach ($storage_types as $storage_type => $storage) {
						echo '<label title="' . esc_attr($storage['description']) . '"><input type="radio" name="aviberry_storage_type" value="' . esc_attr($storage_type) . '"';
						if ($storage_type === $current_storage_type)
							echo ' checked="checked"';
						echo '/>' . esc_html($storage['caption']) . '</label><br />';
					}
					?>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="aviberry_storage_user"><?php _e('User name'); ?></label></th>
				<td><input type="text" class="regular-text" id="aviberry_storage_user" name="aviberry_storage_user" value="<?php form_option("aviberry_storage_user"); ?>" title="<?php _e('User name to log into storage.'); ?>" /></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="aviberry_storage_pass"><?php _e('Password'); ?></label></th>
				<td><input type="text" class="regular-text" id="aviberry_storage_pass" name="aviberry_storage_pass" value="<?php form_option("aviberry_storage_pass"); ?>" title="<?php _e('User password to log into storage.'); ?>" /></td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="aviberry_storage_host"><?php _e('Host'); ?></label></th>
				<td>
					<input type="text" class="regular-text" id="aviberry_storage_host" name="aviberry_storage_host" value="<?php form_option("aviberry_storage_host"); ?>" title="<?php _e('Storage host name.'); ?>" />
					<br/><?php _e('Example:'); ?> <span class="aviberry_param_example"><?php
						switch ($current_storage_type) {
							case 's3':
								echo AVIBERRY_S3_HOST;
								break;
							default:
								_e('example.com');
						} ?></span>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="aviberry_storage_port"><?php _e('Port'); ?></label></th>
				<td>
					<input type="text" class="regular-text" id="aviberry_storage_port" name="aviberry_storage_port" value="<?php form_option("aviberry_storage_port"); ?>" title="<?php _e('Storage port (if required).'); ?>" />
					<br/><?php _e('Example:'); ?> <span class="aviberry_param_example"><?php
						switch ($current_storage_type) {
							case 'ftp':
							case 'wp_media_lib_ftp':
								echo 21;
								break;
							case 'ftps':
							case 'wp_media_lib_ftps':
								echo 22;
								break;
						} ?></span>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="aviberry_storage_path"><?php
					switch ($current_storage_type) {
						case 'wp_media_lib_ftp':
						case 'wp_media_lib_ftps':
							echo aviberryPlugin::i18n('labelPathWordpressMediaLibrary');
							break;
						default:
							echo aviberryPlugin::i18n('labelStoragePath');
					} ?></label></th>
				<td>
					<input type="text" class="regular-text" id="aviberry_storage_path" name="aviberry_storage_path" value="<?php form_option("aviberry_storage_path"); ?>" title="<?php _e('Storage path (if required).'); ?>" />
					<br/><?php _e('Example:'); ?> <span class="aviberry_param_example"><?php
						switch ($current_storage_type) {
							case 'wp_media_lib_ftp':
							case 'wp_media_lib_ftps':
								echo aviberryPlugin::i18n('examplePathToWordpressMediaLibrary');
								break;
							case 'ftp':
							case 'ftps':
								echo aviberryPlugin::i18n('examplePath');
								break;
							case 's3':
								echo aviberryPlugin::i18n('exampleBacket');
								break;
							} ?></span>
				</td>
			</tr>
		</table>
		<br/>
		
		<h3><?php _e('Publish'); ?></h3>
		<table class="form-table">
			<tr>
				<th scope="row" colspan="2" class="th-full">
					<label for="aviberry_use_player">
						<input name="aviberry_use_player" type="checkbox" id="aviberry_use_player" value="1"<?php checked('1', aviberryPlugin::getOption('aviberry_use_player')); ?> title="<?php _e('Whether to use Aviberry Player for video in published posts.'); ?>" />
						<?php _e('Use Aviberry Player to publish video'); ?>
					</label>
				</th>
			</tr>
			<tr valign="top">
				<th scope="row"><label for="aviberry_player_embedding_type"><?php _e('Player embedding type'); ?></label></th>
				<td>
					<?php
					$embedding_types = array(
						'javascript' => array(
							'caption'     => 'JavaScript',
							'description' => __('Use JavaScript on client side to replace native "a" tag with the player. If you disable plugin, your posts will be not needed in modifications.')
						),
						'shortcode' => array(
							'caption'     => 'ShortCode',
							'description' => __('Use shortcode [aviberry-player] in post to embed the player on server side instead of native "a" tag. No need in JavaScript on client side, but if you disable plugin, your posts will be nedded to replace this shortcode.')
						)
					);
					$current_embedding_type = aviberryPlugin::getOption('aviberry_player_embedding_type');
					 
					foreach ($embedding_types as $embedding_type => $embedding) {
						echo '<label title="' . esc_attr($embedding['description']) . '"><input type="radio" name="aviberry_player_embedding_type" value="' . esc_attr($embedding_type) . '"';
						if ($embedding_type === $current_embedding_type)
							echo ' checked="checked"';
						echo '/>' . esc_html($embedding['caption']) . '</label><br />';
					}
					?>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row"><?php _e('Player size') ?></th>
				<td>
					<fieldset>
						<legend class="screen-reader-text"><span><?php _e('Player size'); ?></span></legend>
						<label for="player_width"><?php _e('Width'); ?></label>
						<input name="aviberry_player_width" type="text" id="aviberry_player_width" value="<?php esc_attr_e(aviberryPlugin::getOption('aviberry_player_width')); ?>" class="small-text" />
						<label for="aviberry_player_height"><?php _e('Height'); ?></label>
						<input name="aviberry_player_height" type="text" id="aviberry_player_height" value="<?php esc_attr_e(aviberryPlugin::getOption('aviberry_player_height')); ?>" class="small-text" />
					</fieldset>
				</td>
			</tr>
		</table>
		<br/>

		<h3><?php _e('Miscellaneous'); ?></h3>
		<table class="form-table">
			<tr>
				<th scope="row" colspan="2" class="th-full">
					<label for="aviberry_display_tooltips">
						<input name="aviberry_display_tooltips" type="checkbox" id="aviberry_display_tooltips" value="1"<?php checked('1', aviberryPlugin::getOption('aviberry_display_tooltips')); ?> title="<?php _e('Whether to display more observable tooltips.'); ?>" />
						<?php _e('Display more observable tooltips'); ?>
					</label>
				</th>
			</tr>
		</table>
		<br/>
		
		<p class="submit">
			<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
		</p>
		
		<p>
			Please feel free to contact <a href="mailto:aviberry@movavi.com">aviberry@movavi.com</a> with any questions.
		</p>
	</form>
</div>